What does this implement/fix? Explain your changes.
---------------------------------------------------
...

Does this close any currently open issues?
------------------------------------------
...


Any relevant logs, error output, etc?
-------------------------------------
(If it’s long, please paste to https://ghostbin.com/ or https://bpaste.net and insert the link here.)

Any other comments?
-------------------
...

Where has this been tested?
---------------------------

**Operating System:** ...

**Platform:** ...

**Target Platform:** ...
